@@ -1,4 +1,4 @@
 from root_numpy import *
 from root_numpy_warnings import *
-from nputil import stretch
+from util import *
 from info import __version__
